function [I,Y,x]=nula(x0,xF,tol,iterM)
%Funkcija [I,Y,x]=nula(x0,xF,tol,iterM) odredjuje nulu tablicno zadate
%funkcije u tablica.m koriscenjem metode regula-falsi.
%
%Ulazni argumenti su:
%     x0 - pocetna vrednost iterativnog niza
%     xF - fiksirana tacka u metodi regula-falsi
%     tol - tacnost
%     iterM - maksimalni dozvoljeni broj iteracija
%Izlazni argumenti su:
%     I - vektor [1:iter] gde je iter broj iteracija
%         dok se ne zadovolji tacnost tol ili iterM
%     Y - vrednosti tablicno zadate funkcije u tackama iterativnog niza
%         izracunata pomocu I Njutnovog interpolacionog polinoma
%     x - nula tablicno zadate funkcije
%
tablica;
h=X(2)-X(1);
koef=Njutn1(); %Koeficijenti I Njutnovog int.pol. po q
f=@(x)polyval(koef,(x-X(1))/h); %Anonimna f-ja koja racuna vrednost 
                                %I Njutnovog polinoma u x (q=(x-X(1)/h))
Y=zeros(1,iterM);% Y ima najvise iterM elemenata
iter=0;
while iter<iterM
    x1=x0-(f(x0)/(f(xF)-f(x0)))*(xF-x0); %regula-falsi
    iter=iter+1; 
    Y(iter)=f(x1);
    greska=abs(x1-x0);
    if greska<tol
        break;
    end
    x0=x1;
end
I=1:iter;
Y=Y(1:iter);
if iter==iterM && greska<tol
    disp('Zadovoljena je tacnost i dostignut max br iteracija.');
elseif iter==iterM 
    disp('Zadovoljen je maksimalan broj iteracija.');
else
    disp('Zadovoljena je tacnost tol');
end
x=x1;